-
-
- ${_("Instructor-led courses progress at the pace that the course author sets. You can configure release dates for course content and due dates for assignments.")}
+
+
+ ${_("Instructor-paced courses progress at the pace that the course author sets. You can configure release dates for course content and due dates for assignments.")}
diff --git a/common/test/acceptance/pages/studio/settings.py b/common/test/acceptance/pages/studio/settings.py
index 288a089c56..2adfb161ca 100644
--- a/common/test/acceptance/pages/studio/settings.py
+++ b/common/test/acceptance/pages/studio/settings.py
@@ -151,7 +151,7 @@ class SettingsPage(CoursePage):
@course_pacing.setter
def course_pacing(self, pacing):
"""
- Sets the course to either self-paced or instructor-led by checking
+ Sets the course to either self-paced or instructor-paced by checking
the appropriate radio button.
"""
self.wait_for_element_presence(self.checked_pacing_css, 'course pacing controls present')
diff --git a/lms/djangoapps/courseware/tests/test_course_info.py b/lms/djangoapps/courseware/tests/test_course_info.py
index 3d1f18b3de..9feb521a23 100644
--- a/lms/djangoapps/courseware/tests/test_course_info.py
+++ b/lms/djangoapps/courseware/tests/test_course_info.py
@@ -126,7 +126,7 @@ class SelfPacedCourseInfoTestCase(LoginEnrollmentTestCase, SharedModuleStoreTest
def setUp(self):
super(SelfPacedCourseInfoTestCase, self).setUp()
- self.instructor_led_course = CourseFactory.create(self_paced=False)
+ self.instructor_paced_course = CourseFactory.create(self_paced=False)
self.self_paced_course = CourseFactory.create(self_paced=True)
self.setup_user()
@@ -141,8 +141,8 @@ class SelfPacedCourseInfoTestCase(LoginEnrollmentTestCase, SharedModuleStoreTest
resp = self.client.get(url)
self.assertEqual(resp.status_code, 200)
- def test_num_queries_instructor_led(self):
- self.fetch_course_info_with_queries(self.instructor_led_course, 14, 4)
+ def test_num_queries_instructor_paced(self):
+ self.fetch_course_info_with_queries(self.instructor_paced_course, 14, 4)
def test_num_queries_self_paced(self):
self.fetch_course_info_with_queries(self.self_paced_course, 14, 4)
diff --git a/lms/djangoapps/courseware/tests/test_self_paced_overrides.py b/lms/djangoapps/courseware/tests/test_self_paced_overrides.py
index 7142927e1e..26a49cf07e 100644
--- a/lms/djangoapps/courseware/tests/test_self_paced_overrides.py
+++ b/lms/djangoapps/courseware/tests/test_self_paced_overrides.py
@@ -42,9 +42,9 @@ class SelfPacedDateOverrideTest(ModuleStoreTestCase):
inject_field_overrides((course, section), course, UserFactory.create())
return (course, section)
- def test_instructor_led(self):
- __, il_section = self.setup_course("Instructor Led Course", False)
- self.assertEqual(self.due_date, il_section.due)
+ def test_instructor_paced(self):
+ __, ip_section = self.setup_course("Instructor Paced Course", False)
+ self.assertEqual(self.due_date, ip_section.due)
def test_self_paced(self):
__, sp_section = self.setup_course("Self-Paced Course", True)
diff --git a/lms/djangoapps/courseware/tests/test_views.py b/lms/djangoapps/courseware/tests/test_views.py
index 7bd8acc4c6..e32d3078a4 100644
--- a/lms/djangoapps/courseware/tests/test_views.py
+++ b/lms/djangoapps/courseware/tests/test_views.py
@@ -822,7 +822,7 @@ class ProgressPageTests(ModuleStoreTestCase):
)
@ddt.unpack
def test_query_counts(self, (sql_calls, mongo_calls, self_paced), self_paced_enabled):
- """Test that query counts remain the same for self-paced and instructor-led courses."""
+ """Test that query counts remain the same for self-paced and instructor-paced courses."""
SelfPacedConfiguration(enabled=self_paced_enabled).save()
self.setup_course(self_paced=self_paced)
with self.assertNumQueries(sql_calls), check_mongo_calls(mongo_calls):
diff --git a/common/test/acceptance/tests/studio/test_studio_settings_details.py b/common/test/acceptance/tests/studio/test_studio_settings_details.py
index 72a9793543..7c361b7230 100644
--- a/common/test/acceptance/tests/studio/test_studio_settings_details.py
+++ b/common/test/acceptance/tests/studio/test_studio_settings_details.py
@@ -209,11 +209,11 @@ class CoursePacingTest(StudioSettingsDetailsTest):
# Set the course start date to tomorrow in order to allow setting pacing
self.course_fixture.add_course_details({'start_date': datetime.now() + timedelta(days=1)})
- def test_default_instructor_led(self):
+ def test_default_instructor_paced(self):
"""
Test that the 'instructor led' button is checked by default.
"""
- self.assertEqual(self.settings_detail.course_pacing, 'Instructor-Led')
+ self.assertEqual(self.settings_detail.course_pacing, 'Instructor-Paced')
def test_self_paced(self):
"""
@@ -209,11 +209,11 @@ class CoursePacingTest(StudioSettingsDetailsTest):
"""
- Test that the 'instructor led' button is checked by default.
+ Test that the 'instructor paced' button is checked by default.
"""